@@ -60,6 +60,38 @@ class Stacks(BaseObject):
         response.raise_for_status()
         return self
 
+    def purge(self, url, recursive=True, invalidateOnly=False, purgeAllDynamic=False, headers=[], purgeSelector=[]):
+        purgeSelectors = ["selectorType", "selectorName", "selectorValue", "selectorValueDelimter"]
+
+        for value in purgeSelector:
+            if not value in purgeSelectors:
+                raise ValueError(f"{value} is not a valid purgeSelector: {purgeSelectors}")
+
+        data = {
+            "items": [
+                {
+                    "url": url,
+                    "recursive": recursive,
+                    "headers": headers,
+                    "invalidateOnly": invalidateOnly,
+                    "purgeAllDynamic": purgeAllDynamic,
+                    "purgeSelector": purgeSelector
+                }
+            ]
+        }
+
+        response = self._client.post("/cdn/v1/stacks/{}/purge".format(self.id), json=data)
+        response.raise_for_status()
+
+        return self.loaddict(response.json())
+
+    def purge_status(self, purge_id):
+
+        response = self._client.get(f"/cdn/v1/stacks/{self.id}/purge/{purge_id}")
+        response.raise_for_status()
+
+        return self.loaddict(response.json())
+
     def cdnsites(self):
         return CdnSites(self._client, self.id)
 
